from sawsi.aws import shared
from sawsi.aws.sms import wrapper


class SMSAPI:
    """
    키 등을 관리하는 API
    """
    def __init__(self, region_name, credentials=None):
        """
        :param bucket_name:
        :param credentials: {
            "aws_access_key_id": "str",
            "aws_secret_access_key": "str",
            "region_name": "str",
            "profile_name": "str",
        }
        """
        self.boto3_session = shared.get_boto_session(credentials)
        self.region_name = region_name
        self.sms = wrapper.SMS(self.boto3_session, region_name)

    def send_sms(self, phone, message):
        response = self.sms.send_sms(phone, message)
        return response



import tempfile
from sawsi.aws import shared


class S3:
    def __init__(self, boto3_session, region=shared.DEFAULT_REGION):
        self.client = boto3_session.client('s3', region_name=region)
        self.resource = boto3_session.resource('s3', region_name=region)
        self.region = region

    def init_bucket(self, bucket_name, acl='private'):
        self.create_bucket(bucket_name, acl)

    def create_bucket(self, bucket_name, acl='private'):
        response = self.client.create_bucket(
            ACL=acl,
            Bucket=bucket_name,
            CreateBucketConfiguration={
                'LocationConstraint': self.region
            }
        )
        return response

    def upload_binary(self, bucket_name, file_name, binary):
        with tempfile.TemporaryFile() as tmp:
            tmp.write(binary)
            tmp.seek(0)
            response = self.client.upload_fileobj(tmp, bucket_name, file_name)
            return response

    def delete_binary(self, bucket_name, file_name):
        return self.resource.Object(bucket_name, file_name).delete()

    def download_binary(self, bucket_name, file_name):
        with tempfile.NamedTemporaryFile() as data:
            self.client.download_fileobj(bucket_name, file_name, data)
            data.seek(0)
            return data.read()

    def delete_bucket(self, bucket_name):
        response = self.client.delete_bucket(
            Bucket=bucket_name
        )
        return response

    def upload_file(self, bucket_name, file_bytes, file_name, content_type='text/html'):
        """
        파일을 올림, 컨텐츠 타입 고려함
        :param bucket_name:
        :param file_bytes:
        :param file_name:
        :param content_type:
        :return:
        """
        response = self.client.put_object(
            Bucket=bucket_name,
            Key=file_name,
            Body=file_bytes,
            ContentType=content_type,
            ACL='public-read',
        )
        return response



import boto3
from sawsi.aws import shared


class CodeCommitAPI:
    """
    S3 를 활용하는 커스텀 ORM 클래스
    """
    def __init__(self, credentials=None, region=shared.DEFAULT_REGION):
        """
        :param credentials: {
            "aws_access_key_id": "str",
            "aws_secret_access_key": "str",
            "region_name": "str",
            "profile_name": "str",
        }
        """
        self.boto3_session = shared.get_boto_session(credentials)
        self.cache = {}
        self.client = boto3.client('codecommit', region_name=region)

    def get_file(self, repository_name, commit_specifier, file_path):
        # 커밋 기반으로 파일 가쟈오기
        response = self.client.get_file(
            repositoryName=repository_name,
            commitSpecifier=commit_specifier,
            filePath=file_path
        )
        return response


if __name__ == '__main__':
    code_commit = CodeCommitAPI()
    r = code_commit.get_file('product_pipe_serverless', 'cdb53f7e0f357964544a8c274687e31281556ad1', 'aws/shared.py')
    fileContent = r['fileContent']
    print(fileContent.decode())


from sawsi.aws import shared
from sawsi.aws.s3 import wrapper
from secrets import token_urlsafe


class S3API:
    """
    S3 를 활용하는 커스텀 ORM 클래스
    """
    def __init__(self, bucket_name, credentials=None, region=shared.DEFAULT_REGION):
        """
        :param bucket_name:
        :param credentials: {
            "aws_access_key_id": "str",
            "aws_secret_access_key": "str",
            "region_name": "str",
            "profile_name": "str",
        }
        """
        self.boto3_session = shared.get_boto_session(credentials)
        self.cache = {}
        self.bucket_name = bucket_name
        self.s3 = wrapper.S3(self.boto3_session, region=region)

    def init_s3_bucket(self, acl='private'):
        """
        실제 버킷 생성
        :return:
        """
        return self.s3.init_bucket(self.bucket_name, acl)

    def upload_binary(self, file_name, binary):
        return self.s3.upload_binary(self.bucket_name, file_name, binary)

    def delete_binary(self, file_name):
        return self.s3.delete_binary(self.bucket_name, file_name)

    def download_binary(self, file_name):
        return self.s3.download_binary(self.bucket_name, file_name)

    def upload_file_and_return_url(self, file_bytes, extension, content_type, use_accelerate=False):
        """
        파일을 업로드하고 URL 을 반환합니다.
        만천하에 공개되기 때문에 공개해도 괜찮은 파일만 사용해야 함.
        :param file_bytes:
        :param extension:
        :param content_type:
        :param use_accelerate:
        :return:
        """
        if use_accelerate:
            base_url = f'https://{self.bucket_name}.s3-accelerate.amazonaws.com/'  # 전송 가속화
        else:
            base_url = f'https://{self.bucket_name}.s3.{self.s3.region}.amazonaws.com/'
        file_id = f'{token_urlsafe(32)}.{extension}'
        response = self.s3.upload_file(self.bucket_name, file_bytes, file_id, content_type)
        return base_url + file_id



from setuptools import setup, find_packages

setup(
    name="sawsi",
    version="1.7",
    packages=find_packages(),
    install_requires=[
        'boto3==1.28.43',
        'PyJWT==2.8.0',
        'requests==2.31.0'
    ],
)
